@@ -137,6 +137,15 @@ sub search : Global {
 
 	my ($path_pages) = $c->model('DBIC::Page')->path_pages( $key ) ;
     my $page=$path_pages->[ @$path_pages - 1 ];
+
+# skip search result depending on permissions
+    my $user;
+    if ($c->config->{'permissions'}{'check_permission_on_view'}) {
+        if ($c->user_exists()) { $user = $c->user->obj; }
+        my $perms = $c->check_permissions($page->path, $user);
+        next unless $perms->{'view'};
+    }
+
 # add a snippet of text containing the search query
 	my $content = $strip->parse( $page->content->formatted($c) );
 	$strip->eof;
